/*
 * @author lsy
 * @date   2019-09-16
 **/
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:gmalpha_flutter/PrestigeModel/page/reputation/ReputationsModel.dart';
import 'package:gmalpha_flutter/PrestigeModel/service/remote/entity/PrestigeEntity.dart';
import 'package:cached_network_image/cached_network_image.dart';

class ReputationsPage extends StatefulWidget {
  ReputationsModel _model;

  ReputationsPage(String cookie) {
    _model = new ReputationsModel(cookie);
  }

  @override
  State<StatefulWidget> createState() => ReputationsState(_model);
}

class ReputationsState extends State<ReputationsPage> {
  ReputationsModel _model;

  ReputationsState(this._model);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
            title: Text(
              '我的专家声望',
              style: TextStyle(fontSize: 16),
            ),
            centerTitle: true,
            leading: IconButton(
//          alignment: Alignment.centerLeft,
              onPressed: () => Navigator.pop(context),
//          padding: EdgeInsets.fromLTRB(22, 0, 0, 0),
              icon: Icon(
                Icons.keyboard_arrow_left,
              ),
            )),
        body: StreamBuilder<PrestigeEntity>(
          stream: _model.prestigeLive.stream,
          initialData: _model.prestigeLive.data,
          builder: (context, data) {
            if (data.data == null) {
              return loadingItem();
            }
            if (data.data.error != 0 || data.data.data == null) {
              return errorItem(data.data.message);
            }
            return Column(
              children: <Widget>[
                Container(
                  margin: EdgeInsets.fromLTRB(17, 24, 0, 0),
                  child: MyText(
                      16.0, data.data.data.introduce[0].question, 0xff323232),
                ),
                Container(
                  margin: EdgeInsets.fromLTRB(19, 16, 0, 0),
                  child: MyText(
                      13.0, data.data.data.introduce[0].answer, 0xff8E8E8E),
                ),
                ListView.builder(
                    itemCount: data.data.data.reputations.length,
                    itemBuilder: (context, index) {
                      return listItem(data, index);
                    }),
              ],
            );
          },
        ));
  }

  Widget listItem(AsyncSnapshot<PrestigeEntity> data, int index) {
    int allSize = data.data.data.reputations[index].expertTags.length;
    int bringSize = 0;
    for (var item in data.data.data.reputations[index].expertTags) {
      if (item.level > 0) {
        bringSize++;
      }
    }
    return Column(
      children: <Widget>[
        Container(
          margin: EdgeInsets.fromLTRB(0, 32, 0, 0),
          width: double.maxFinite,
          height: 30,
          child: Row(
            children: <Widget>[
              Container(
                margin: EdgeInsets.fromLTRB(16, 0, 0, 0),
                child: MyText(14.0, data.data.data.reputations[index].category,
                    0xffffffff),
              ),
              Expanded(
                child: Container(),
              ),
              Container(
                margin: EdgeInsets.fromLTRB(0, 0, 16, 0),
                child: MyText(14.0, "${bringSize}/${allSize}", 0xffffffff),
              )
            ],
          ),
        ),
        GridView.builder(
            gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                crossAxisCount: 3, mainAxisSpacing: 4, crossAxisSpacing: 10.0),
            itemBuilder: (context, gridIndex) {
              var item =
                  data.data.data.reputations[index].expertTags[gridIndex];
              bool isBright = item.level > 0;
              return Column(
                children: <Widget>[
                  isBright
                      ? CachedNetworkImage(imageUrl: item.lightBadge)
                      : CachedNetworkImage(imageUrl: item.grayBadge),
                  Container(
                      margin: EdgeInsets.fromLTRB(0, 5, 0, 0),
                      child: isBright
                          ? MyText(13.0, "Lv${item.level} ${item.tagName}",
                              0xff8E8E8E)
                          : MyText(13.0, "${item.tagName}", 0xffC4C4C4))
                ],
              );
            })
      ],
    );
  }

  Widget errorItem(String reason) {
    return Center(
      child: Text("$reason"),
    );
  }

  Widget loadingItem() {
    return CircularProgressIndicator();
  }

  Text MyText(double size, String text, int color) {
    return Text(
      text,
      style: TextStyle(fontSize: size, color: Color(color)),
    );
  }

  @override
  void dispose() {
    super.dispose();
    _model.dispose();
  }
}
